from ._subscript import table_subscript
from ._smallcaps import table_smallcaps
from ._emoji import table_emoji
from ._bold import table_bold
from ._handwriting import table_handwriting
from ._italic import table_italic
from ._demonic import table_demonic
from ._fancy import table_fancy

__all__ = [
    'table_subscript',
    'table_smallcaps',
    'table_emoji',
    'table_bold',
    'table_handwriting',
    'table_italic',
    'table_demonic',
    'table_fancy'
]
